@@ -6,7 +6,7 @@ use LWP;
 use LWP::Protocol::https;
 use JSON;
 
-our $VERSION = 0.11;
+our $VERSION = 0.12;
 
 sub new {
   my ($class, %args) = @_;
@@ -34,13 +34,17 @@ sub new {
 
 sub _login {
   my $self = shift;
-  my $res = $self->{ua}->post('https://login.vk.com/?act=login', {
+  my $lpage = $self->{ua}->get('http://vk.com/login.php');
+  return 0 unless ($lpage->is_success); # network problem?
+  my $action = $1 if $lpage->content =~ /action=\"(.+?)\"/;
+  return 1 unless $action; # log in already? go to the next step
+  my $res = $self->{ua}->post($action, {
+  #my $res = $self->{ua}->post('https://login.vk.com/?act=login', {
       email => $self->{login},
       pass => $self->{password},
     });
-  print $res->header('location'),"\n",$res->content;
   return 0 if $res->status_line ne "302 Found";
-  return 0 if $res->header('location') !~ /act=slogin&role=fast/; # bad login or password
+  return 0 if $res->header('location') !~ /__q_hash/;
   $res = $self->{ua}->get($res->header('location'));
   return 0 unless $res->is_success;
   return $res->message;
